@@ -1,4 +1,4 @@
-"""
+'''
 # CDK Construct Libray for AWS XXX
 
 <!--BEGIN STABILITY BANNER-->---
@@ -10,7 +10,7 @@
 <!--END STABILITY BANNER-->
 
 A short description here.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -34,12 +34,12 @@ class KinesisDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-logs-destinations.KinesisDestination",
 ):
-    """Use a Kinesis stream as the destination for a log subscription."""
+    '''Use a Kinesis stream as the destination for a log subscription.'''
 
     def __init__(self, stream: aws_cdk.aws_kinesis.IStream) -> None:
-        """
+        '''
         :param stream: -
-        """
+        '''
         jsii.create(KinesisDestination, self, [stream])
 
     @jsii.member(jsii_name="bind")
@@ -48,7 +48,7 @@ class KinesisDestination(
         scope: aws_cdk.core.Construct,
         _source_log_group: aws_cdk.aws_logs.ILogGroup,
     ) -> aws_cdk.aws_logs.LogSubscriptionDestinationConfig:
-        """Return the properties required to send subscription events to this destination.
+        '''Return the properties required to send subscription events to this destination.
 
         If necessary, the destination can use the properties of the SubscriptionFilter
         object itself to configure its permissions to allow the subscription to write
@@ -59,8 +59,8 @@ class KinesisDestination(
 
         :param scope: -
         :param _source_log_group: -
-        """
-        return jsii.invoke(self, "bind", [scope, _source_log_group])
+        '''
+        return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, _source_log_group]))
 
 
 @jsii.implements(aws_cdk.aws_logs.ILogSubscriptionDestination)
@@ -68,12 +68,12 @@ class LambdaDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-logs-destinations.LambdaDestination",
 ):
-    """Use a Lamda Function as the destination for a log subscription."""
+    '''Use a Lamda Function as the destination for a log subscription.'''
 
     def __init__(self, fn: aws_cdk.aws_lambda.IFunction) -> None:
-        """
+        '''
         :param fn: -
-        """
+        '''
         jsii.create(LambdaDestination, self, [fn])
 
     @jsii.member(jsii_name="bind")
@@ -82,7 +82,7 @@ class LambdaDestination(
         scope: aws_cdk.core.Construct,
         log_group: aws_cdk.aws_logs.ILogGroup,
     ) -> aws_cdk.aws_logs.LogSubscriptionDestinationConfig:
-        """Return the properties required to send subscription events to this destination.
+        '''Return the properties required to send subscription events to this destination.
 
         If necessary, the destination can use the properties of the SubscriptionFilter
         object itself to configure its permissions to allow the subscription to write
@@ -93,8 +93,8 @@ class LambdaDestination(
 
         :param scope: -
         :param log_group: -
-        """
-        return jsii.invoke(self, "bind", [scope, log_group])
+        '''
+        return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, log_group]))
 
 
 __all__ = [
